==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>No hay límite seleccionado.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>Contorno no se cierra en el punto %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>Cada objeto de frontera debe ser una línea, arco, círculo, arco elíptico, una elipse, polilínea o spline. Encuentran:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Rayado</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>Dibuje un sombreado o un relleno sólido</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Rayado</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Relleno sólido</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Patrón de rayado</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Patrón</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Ángulo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Escala:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">No hay límite seleccionado.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">Contorno no se cierra en el punto %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">Cada objeto de frontera debe ser una línea, arco, círculo, arco elíptico, una elipse, polilínea o spline. Encuentran:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Menú rayado</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Mostrar menú rayado</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Rayado</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">Dibuje un sombreado o un relleno sólido</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Rayado</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Relleno sólido</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Patrón de rayado</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Patrón</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Ángulo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Escala:</translation>
    </message>
</context>
</TS>
